@@ -34,6 +34,8 @@ class AbstractModel : public QAbstractListModel
 
         int count() const;
 
+        int columnCount(const QModelIndex &parent = QModelIndex()) const;
+
         Q_INVOKABLE virtual bool trigger(int row, const QString &actionId, const QVariant &argument) = 0;
 
         Q_INVOKABLE virtual AbstractModel *modelForRow(int row);
@@ -42,7 +44,6 @@ class AbstractModel : public QAbstractListModel
 
     Q_SIGNALS:
         void countChanged() const;
-        void appLaunched(const QString& storageId) const;
 };
 
 #endif
