@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2012 by Aurélien Gâteau <agateau@kde.org>               *
- *   Copyright (C) 2014 by Eike Hein <hein@kde.org>                        *
+ *   Copyright (C) 2014-2015 by Eike Hein <hein@kde.org>                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,64 +21,59 @@
 #include "recentdocsmodel.h"
 #include "actionlist.h"
 
-#include <QSet>
+#include <QIcon>
 
-#include <KDesktopFile>
-#include <KDirWatch>
 #include <KFileItem>
 #include <KLocalizedString>
-#include <KRecentDocument>
 #include <KRun>
 
-DocEntry::DocEntry(const QString &name, const QString &icon,
-    const QString &url, const QString &desktopPath)
+#include <KActivitiesExperimentalStats/Cleaning>
+#include <KActivitiesExperimentalStats/ResultModel>
+#include <KActivitiesExperimentalStats/Terms>
+
+namespace KAStats = KActivities::Experimental::Stats;
+
+using namespace KAStats;
+using namespace KAStats::Terms;
+
+RecentDocsModel::RecentDocsModel(QObject *parent) : ForwardingModel(parent)
 {
-    m_name = name;
-    m_icon = QIcon::fromTheme(icon);
-    m_url = url;
-    m_desktopPath = desktopPath;
-}
-
-RecentDocsModel::RecentDocsModel(QObject *parent) : AbstractModel(parent)
-{
-    KDirWatch *watch = new KDirWatch(this);
-    watch->addDir(KRecentDocument::recentDocumentDirectory());
-
-    connect(watch, SIGNAL(created(QString)), SLOT(refresh()));
-    connect(watch, SIGNAL(deleted(QString)), SLOT(refresh()));
-    connect(watch, SIGNAL(dirty(QString)), SLOT(refresh()));
-
     refresh();
 }
 
 RecentDocsModel::~RecentDocsModel()
 {
-    qDeleteAll(m_entryList);
 }
 
 QVariant RecentDocsModel::data(const QModelIndex &index, int role) const
 {
-    if (!index.isValid() || index.row() >= m_entryList.count()) {
+    if (!index.isValid()) {
+        return QVariant();
+    }
+
+    const QUrl url(sourceModel()->data(index, ResultModel::ResourceRole).toString());
+    const KFileItem fileItem(url);
+
+    if (!url.isValid() || !fileItem.isFile()) {
         return QVariant();
     }
 
     if (role == Qt::DisplayRole) {
-        return m_entryList.at(index.row())->name();
+        return url.fileName();
     } else if (role == Qt::DecorationRole) {
-        return m_entryList.at(index.row())->icon();
+        return QIcon::fromTheme(fileItem.iconName(), QIcon::fromTheme("unknown"));
     } else if (role == Kicker::HasActionListRole) {
         return true;
     } else if (role == Kicker::ActionListRole) {
-        KFileItem item(QUrl(m_entryList.at(index.row())->url()));
-        QVariantList actionList = Kicker::createActionListForFileItem(item);
+        QVariantList actionList = Kicker::createActionListForFileItem(fileItem);
 
-        actionList.prepend(Kicker::createSeparatorActionItem());
-
-        const QVariantMap &forgetAllAction = Kicker::createActionItem(i18n("Forget All Documents"), "forgetAll");
-        actionList.prepend(forgetAllAction);
+        actionList << Kicker::createSeparatorActionItem();
 
         const QVariantMap &forgetAction = Kicker::createActionItem(i18n("Forget Document"), "forget");
-        actionList.prepend(forgetAction);
+        actionList << forgetAction;
+
+        const QVariantMap &forgetAllAction = Kicker::createActionItem(i18n("Forget All Documents"), "forgetAll");
+        actionList << forgetAllAction;
 
         return actionList;
     }
@@ -86,29 +81,30 @@ QVariant RecentDocsModel::data(const QModelIndex &index, int role) const
     return QVariant();
 }
 
-int RecentDocsModel::rowCount(const QModelIndex &parent) const
-{
-    return parent.isValid() ? 0 : m_entryList.count();
-}
-
 bool RecentDocsModel::trigger(int row, const QString &actionId, const QVariant &argument)
 {
-    if (row < 0 || row >= m_entryList.count()) {
+    if (row < 0 || row >= rowCount()) {
         return false;
     }
 
-    QUrl url(m_entryList.at(row)->url());
+    QUrl url(sourceModel()->data(sourceModel()->index(row, 0), ResultModel::ResourceRole).toString());
 
     if (actionId.isEmpty()) {
         new KRun(url, 0);
 
         return true;
     } else if (actionId == "forget") {
-        forget(row);
+        if (sourceModel()) {
+            ResultModel *resultModel = static_cast<ResultModel *>(sourceModel());
+            resultModel->forgetResource(row);
+        }
 
         return false;
     } else if (actionId == "forgetAll") {
-        forgetAll();
+        if (sourceModel()) {
+            ResultModel *resultModel = static_cast<ResultModel *>(sourceModel());
+            resultModel->forgetAllResources();
+        }
 
         return true;
     }
@@ -126,68 +122,19 @@ bool RecentDocsModel::trigger(int row, const QString &actionId, const QVariant &
 
 void RecentDocsModel::refresh()
 {
-    beginResetModel();
+    QObject *oldModel = sourceModel();
 
-    qDeleteAll(m_entryList);
-    m_entryList.clear();
+    auto query = UsedResources
+                    | RecentlyUsedFirst
+                    | Agent::any()
+                    | Type::any()
+                    | Activity::current()
+                    | Url::file();
 
-    QSet<QString> urls;
+    ResultModel *model = new ResultModel(query);
+    model->setItemCountLimit(15);
 
-    foreach (const QString &path, KRecentDocument::recentDocuments()) {
-        KDesktopFile file(path);
-        QString url = file.readUrl();
+    setSourceModel(model);
 
-        if (urls.contains(url)) {
-            continue;
-        }
-
-        QString name = file.readName();
-
-        if (name.isEmpty()) {
-            name = url;
-        }
-
-        if (name.isEmpty()) {
-            continue;
-        }
-
-        m_entryList << new DocEntry(name, file.readIcon(), url, path);
-
-        urls.insert(url);
-    }
-
-    endResetModel();
-
-    emit countChanged();
-}
-
-void RecentDocsModel::forget(int row)
-{
-    if (row >= m_entryList.count()) {
-        return;
-    }
-    if (QFile::remove(m_entryList.at(row)->desktopPath())) {
-        beginRemoveRows(QModelIndex(), row, row);
-
-        m_entryList.removeAt(row);
-
-        endRemoveRows();
-
-        emit countChanged();
-    }
-}
-
-void RecentDocsModel::forgetAll()
-{
-    beginResetModel();
-
-    for (int row = m_entryList.count() - 1; row >= 0; --row) {
-        if (QFile::remove(m_entryList.at(row)->desktopPath())) {
-            m_entryList.removeAt(row);
-        }
-    }
-
-    endResetModel();
-
-    emit countChanged();
+    delete oldModel;
 }
