@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2012 by Aurélien Gâteau <agateau@kde.org>               *
- *   Copyright (C) 2014 by Eike Hein <hein@kde.org>                        *
+ *   Copyright (C) 2014-2015 by Eike Hein <hein@kde.org>                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -21,26 +21,9 @@
 #ifndef RECENTDOCSMODEL_H
 #define RECENTDOCSMODEL_H
 
-#include "abstractentry.h"
-#include "abstractmodel.h"
+#include "forwardingmodel.h"
 
-class DocEntry : public AbstractEntry
-{
-    public:
-        DocEntry(const QString &name, const QString &icon,
-            const QString &url, const QString &desktopPath);
-
-        EntryType type() const { return RunnableType; }
-
-        QString url() const { return m_url; }
-        QString desktopPath() const { return m_desktopPath; }
-
-    private:
-        QString m_url;
-        QString m_desktopPath;
-};
-
-class RecentDocsModel : public AbstractModel
+class RecentDocsModel : public ForwardingModel
 {
     Q_OBJECT
 
@@ -50,18 +33,10 @@ class RecentDocsModel : public AbstractModel
 
         QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
 
-        int rowCount(const QModelIndex &parent = QModelIndex()) const;
-
         Q_INVOKABLE bool trigger(int row, const QString &actionId, const QVariant &argument);
 
     private Q_SLOTS:
         void refresh();
-
-    private:
-        void forget(int row);
-        void forgetAll();
-
-        QList<DocEntry *> m_entryList;
 };
 
 #endif
