@@ -50,6 +50,7 @@
 #include "kickoffadaptor.h"
 // Local
 #include "models.h"
+#include "itemhandlers.h"
 
 #include <Plasma/Applet>
 
@@ -149,7 +150,7 @@ void ApplicationModelPrivate::fillNode(const QString &_relPath, AppNode *node)
             }
 
             AppNode *newnode = new AppNode();
-            newnode->icon = QIcon::fromTheme(p->icon());
+            newnode->icon = QIcon::fromTheme(p->icon(), QIcon::fromTheme("unknown"));
             newnode->appName = p->name();
             newnode->genericName = p->genericName();
             newnode->desktopEntry = p->entryPath();
@@ -264,7 +265,7 @@ void ApplicationModelPrivate::fillNode(const QString &_relPath, AppNode *node)
 
         AppNode *newnode = new AppNode();
         newnode->iconName = icon;
-        newnode->icon = QIcon::fromTheme(icon);
+        newnode->icon = QIcon::fromTheme(icon, QIcon::fromTheme("unknown"));
         newnode->appName = appName;
         newnode->genericName = genericName;
         newnode->relPath = relPath;
@@ -323,6 +324,8 @@ ApplicationModel::ApplicationModel(QObject *parent, bool allowSeparators)
 
     // TODO: remove me again
     reloadMenu();
+
+    UrlItemLauncher::addGlobalHandler(UrlItemLauncher::ExtensionHandler, "desktop", new ServiceItemHandler);
 }
 
 ApplicationModel::~ApplicationModel()
