@@ -114,7 +114,7 @@ public:
         if (append) {
             q->appendRow(documentItem);
         } else {
-            q->insertRow(0, documentItem);
+            q->insertRow(recentApplicationCount, documentItem);
         }
     }
 
@@ -281,5 +281,4 @@ void RecentlyUsedModel::clearRecentDocumentsAndApplications()
 }
 
 
-#include "recentlyusedmodel.moc"
 
