@@ -23,6 +23,7 @@
 #define __K_ACCESS_H__
 
 
+#include <QtCore/QAbstractNativeEventFilter>
 #include <QWidget>
 #include <QColor>
 #include <QLabel>
@@ -30,105 +31,102 @@
 
 
 #include <KUniqueApplication>
-#include <KUrl>
 
 #include <phonon/MediaObject>
 
 #include <X11/Xlib.h>
 #define explicit int_explicit        // avoid compiler name clash in XKBlib.h
+#include <xcb/xkb.h>
 #include <X11/XKBlib.h>
 #undef explicit
 #include <fixx11h.h>
 
-class KDialog;
 class QLabel;
+class KDialog;
 class KComboBox;
 
-class KAccessApp : public KUniqueApplication
+class KAccessApp : public KUniqueApplication, QAbstractNativeEventFilter
 {
-  Q_OBJECT
-
+    Q_OBJECT
 public:
 
-  explicit KAccessApp(bool allowStyles=true, bool GUIenabled=true);
-
-#if 0
-  bool x11EventFilter(XEvent *event);
-#endif
-
-  int newInstance();
-
-  void setXkbOpcode(int opcode);
+    explicit KAccessApp(bool allowStyles = true, bool GUIenabled = true);
+    int newInstance();
+    void setXkbOpcode(int opcode);
+    virtual bool nativeEventFilter(const QByteArray& eventType, void* message, long int* result);
 
 protected:
 
-  void readSettings();
+    void readSettings();
 
-  void xkbStateNotify();
-  void xkbBellNotify(XkbBellNotifyEvent *event);
-  void xkbControlsNotify(XkbControlsNotifyEvent *event);
+    void xkbStateNotify();
+    void xkbBellNotify(xcb_xkb_bell_notify_event_t *event);
+    void xkbControlsNotify(xcb_xkb_controls_notify_event_t *event);
 
 
 private Q_SLOTS:
 
-  void activeWindowChanged(WId wid);
-  void notifyChanges();
-  void applyChanges();
-  void yesClicked();
-  void noClicked();
-  void dialogClosed();
-
+    void activeWindowChanged(WId wid);
+    void notifyChanges();
+    void applyChanges();
+    void yesClicked();
+    void noClicked();
+    void dialogClosed();
+    void toggleScreenReader();
 
 private:
-   void  createDialogContents();
-   void  initMasks();
+    void createDialogContents();
+    void initMasks();
+    void setScreenReaderEnabled(bool enabled);
 
-  int xkb_opcode;
-  unsigned int features;
-  unsigned int requestedFeatures;
+    int xkb_opcode;
+    unsigned int features;
+    unsigned int requestedFeatures;
 
-  bool    _systemBell, _artsBell, _visibleBell, _visibleBellInvert;
-  QColor  _visibleBellColor;
-  int     _visibleBellPause;
+    bool    _systemBell, _artsBell, _visibleBell, _visibleBellInvert;
+    QColor  _visibleBellColor;
+    int     _visibleBellPause;
 
-  bool    _gestures, _gestureConfirmation;
-  bool    _kNotifyModifiers, _kNotifyAccessX;
+    bool    _gestures, _gestureConfirmation;
+    bool    _kNotifyModifiers, _kNotifyAccessX;
 
-  QWidget *overlay;
+    QWidget *overlay;
 
-  Phonon::MediaObject *_player;
-  QString _currentPlayerSource;
+    Phonon::MediaObject *_player;
+    QString _currentPlayerSource;
 
-  WId _activeWindow;
+    WId _activeWindow;
 
-  KDialog *dialog;
-  QLabel *featuresLabel;
-  KComboBox *showModeCombobox;
+    KDialog *dialog;
+    QLabel *featuresLabel;
+    KComboBox *showModeCombobox;
 
-  int keys[8];
-  int state;
+    int keys[8];
+    int state;
+
+    QAction *toggleScreenReaderAction;
 };
 
 
 class VisualBell : public QWidget
 {
-  Q_OBJECT
+    Q_OBJECT
 
 public:
 
-  VisualBell(int pause)
-    : QWidget(( QWidget* )0, Qt::X11BypassWindowManagerHint), _pause(pause)
+    VisualBell(int pause)
+        : QWidget((QWidget*)0, Qt::X11BypassWindowManagerHint), _pause(pause)
     {}
 
 
 protected:
 
-  void paintEvent(QPaintEvent *);
+    void paintEvent(QPaintEvent *);
 
 
 private:
 
-  int _pause;
+    int _pause;
 
 };
 
