@@ -30,9 +30,8 @@
 #include <kconfiggroup.h>
 #include <KLocalizedString>
 #include <KGlobalSettings>
-#include <KToolInvocation>
 
-#include <KUrl>
+#include <QUrl>
 
 #include "../migrationlib/kdelibs4config.h"
 
@@ -80,7 +79,8 @@ void CfgTerminalEmulator::load(KConfig *) {
 
 void CfgTerminalEmulator::save(KConfig *)
 {
-	KConfigGroup config(KSharedConfig::openConfig("kdeglobals"), "General");
+	KSharedConfig::Ptr profile = KSharedConfig::openConfig("kdeglobals", KConfig::SimpleConfig);
+	KConfigGroup config(profile, QLatin1String("General"));
 	const QString terminal = terminalCB->isChecked() ? "konsole" : terminalLE->text();
 	config.writePathEntry("TerminalApplication", terminal); // KConfig::Normal|KConfig::Global);
 
@@ -99,7 +99,7 @@ void CfgTerminalEmulator::save(KConfig *)
 
 void CfgTerminalEmulator::selectTerminalApp()
 {
-	KUrl::List urlList;
+	QList<QUrl> urlList;
 	KOpenWithDialog dlg(urlList, i18n("Select preferred terminal application:"), QString(), this);
 	// hide "Run in &terminal" here, we don't need it for a Terminal Application
 	dlg.hideRunInTerminal();
