@@ -55,11 +55,13 @@
 
 #include <Plasma/Svg>
 
+#include "timedated_interface.h"
 
 #include "helper.h"
 
-Dtime::Dtime(QWidget * parent)
-  : QWidget(parent)
+Dtime::Dtime(QWidget * parent, bool haveTimeDated):
+    QWidget(parent),
+    m_haveTimedated(haveTimeDated)
 {
   setupUi(this);
 
@@ -72,14 +74,17 @@ Dtime::Dtime(QWidget * parent)
   connect(setDateTimeAuto, &QCheckBox::toggled, timeServerList, &QComboBox::setEnabled);
   timeServerList->setEnabled(false);
   timeServerList->setEditable(true);
-  findNTPutility();
-  if (ntpUtility.isEmpty()) {
-      QString toolTip = i18n("No NTP utility has been found. "
-                             "Install 'ntpdate' or 'rdate' command to enable automatic "
-                             "updating of date and time.");
-      setDateTimeAuto->setEnabled(false);
-      setDateTimeAuto->setToolTip(toolTip);
-      timeServerList->setToolTip(toolTip);
+
+  if (!haveTimeDated) {
+    findNTPutility();
+    if (ntpUtility.isEmpty()) {
+        QString toolTip = i18n("No NTP utility has been found. "
+                                "Install 'ntpdate' or 'rdate' command to enable automatic "
+                                "updating of date and time.");
+        setDateTimeAuto->setEnabled(false);
+        setDateTimeAuto->setToolTip(toolTip);
+        timeServerList->setToolTip(toolTip);
+    }
   }
 
   QVBoxLayout *v2 = new QVBoxLayout( timeBox );
@@ -192,21 +197,35 @@ void Dtime::configChanged(){
 
 void Dtime::load()
 {
-  // The config is actually written to the system config, but the user does not have any local config,
-  // since there is nothing writing it.
-  KConfig _config( "kcmclockrc", KConfig::NoGlobals );
-  KConfigGroup config(&_config, "NTP");
-  timeServerList->clear();
-  timeServerList->addItems(config.readEntry("servers",
-    i18n("Public Time Server (pool.ntp.org),\
-asia.pool.ntp.org,\
-europe.pool.ntp.org,\
-north-america.pool.ntp.org,\
-oceania.pool.ntp.org")).split(',', QString::SkipEmptyParts));
-  setDateTimeAuto->setChecked(config.readEntry("enabled", false));
+    QString currentTimeZone;
 
-  if (ntpUtility.isEmpty()) {
-    timeServerList->setEnabled(false);
+    if (m_haveTimedated) {
+        OrgFreedesktopTimedate1Interface timeDatedIface("org.freedesktop.timedate1", "/org/freedesktop/timedate1", QDBusConnection::systemBus());
+        //the server list is not relevant for timesyncd, it fetches it from the network
+        timeServerList->setVisible(false);
+        timeServerLabel->setVisible(false);
+        setDateTimeAuto->setEnabled(timeDatedIface.canNTP());
+        setDateTimeAuto->setChecked(timeDatedIface.nTP());
+
+        currentTimeZone = timeDatedIface.timezone();
+    } else {
+        // The config is actually written to the system config, but the user does not have any local config,
+        // since there is nothing writing it.
+        KConfig _config( "kcmclockrc", KConfig::NoGlobals );
+        KConfigGroup config(&_config, "NTP");
+        timeServerList->clear();
+        timeServerList->addItems(config.readEntry("servers",
+            i18n("Public Time Server (pool.ntp.org),\
+        asia.pool.ntp.org,\
+        europe.pool.ntp.org,\
+        north-america.pool.ntp.org,\
+        oceania.pool.ntp.org")).split(',', QString::SkipEmptyParts));
+        setDateTimeAuto->setChecked(config.readEntry("enabled", false));
+
+        if (ntpUtility.isEmpty()) {
+            timeServerList->setEnabled(false);
+        }
+        currentTimeZone  = KSystemTimeZones::local().name();
   }
 
   // Reset to the current date and time
@@ -222,12 +241,21 @@ oceania.pool.ntp.org")).split(',', QString::SkipEmptyParts));
   //Timezone
   currentZone();
 
-  // read the currently set time zone
-  tzonelist->setSelected(KSystemTimeZones::local().name(), true);
+  tzonelist->setSelected(currentTimeZone, true);
   emit timeChanged(false);
 }
 
-void Dtime::save( QVariantMap& helperargs )
+QString Dtime::selectedTimeZone() const
+{
+    QStringList selectedZones(tzonelist->selection());
+    if (!selectedZones.isEmpty()) {
+        return selectedZones.first();
+    }
+
+    return QString();
+}
+
+QStringList Dtime::ntpServers() const
 {
   // Save the order, but don't duplicate!
   QStringList list;
@@ -241,40 +269,17 @@ void Dtime::save( QVariantMap& helperargs )
     if( list.count() == 10)
       break;
   }
+  return list;
+}
 
-  helperargs["ntp"] = true;
-  helperargs["ntpServers"] = list;
-  helperargs["ntpEnabled"] = setDateTimeAuto->isChecked();
+bool Dtime::ntpEnabled() const
+{
+    return setDateTimeAuto->isChecked();
+}
 
-  if(setDateTimeAuto->isChecked()) {
-    // NTP Time setting - done in helper
-    timeServer = timeServerList->currentText();
-    kDebug() << "Setting date from time server " << timeServer;
-  }
-  else {
-    // User time setting
-    QDateTime dt(date, QTime(timeEdit->time()));
-
-    kDebug() << "Set date " << dt;
-
-    helperargs["date"] = true;
-    helperargs["newdate"] = QString::number(dt.toTime_t());
-    helperargs["olddate"] = QString::number(::time(0));
-  }
-
-  // restart time
-  internalTimer.start( 1000 );
-
-  QStringList selectedZones(tzonelist->selection());
-
-  if (!selectedZones.isEmpty()) {
-    helperargs["tz"] = true;
-    helperargs["tzone"] = selectedZones.first();
-  } else {
-    helperargs["tzreset"] = true; // make the helper reset the timezone
-  }
-
-  currentZone();
+QDateTime Dtime::userTime() const
+{
+    return QDateTime(date, QTime(timeEdit->time()));
 }
 
 void Dtime::processHelperErrors( int code )
@@ -339,14 +344,17 @@ void Kclock::resizeEvent( QResizeEvent * )
 void Kclock::setClockSize(const QSize &size)
 {
     int dim = qMin(size.width(), size.height());
-    QSize newSize = QSize(dim, dim);
+    QSize newSize = QSize(dim, dim) * devicePixelRatio();
 
     if (newSize != m_faceCache.size()) {
         m_faceCache = QPixmap(newSize);
         m_handsCache = QPixmap(newSize);
         m_glassCache = QPixmap(newSize);
+        m_faceCache.setDevicePixelRatio(devicePixelRatio());
+        m_handsCache.setDevicePixelRatio(devicePixelRatio());
+        m_glassCache.setDevicePixelRatio(devicePixelRatio());
 
-        m_theme->resize(newSize);
+        m_theme->resize(QSize(dim, dim));
         m_repaintCache = RepaintAll;
     }
 }
@@ -419,6 +427,8 @@ void Kclock::paintInterface(QPainter *p, const QRect &rect)
 
     // paint face and glass cache
     QRect faceRect = m_faceCache.rect();
+    QRect targetRect = QRect(QPoint(0, 0), QSize(m_faceCache.width() / devicePixelRatio(), m_faceCache.height() / devicePixelRatio()));
+
     if (m_repaintCache == RepaintAll) {
         m_faceCache.fill(Qt::transparent);
         m_glassCache.fill(Qt::transparent);
@@ -428,15 +438,15 @@ void Kclock::paintInterface(QPainter *p, const QRect &rect)
         facePainter.setRenderHint(QPainter::SmoothPixmapTransform);
         glassPainter.setRenderHint(QPainter::SmoothPixmapTransform);
 
-        m_theme->paint(&facePainter, m_faceCache.rect(), "ClockFace");
+        m_theme->paint(&facePainter, targetRect, "ClockFace");
 
         glassPainter.save();
         QRectF elementRect = QRectF(QPointF(0, 0), m_theme->elementSize("HandCenterScrew"));
-        glassPainter.translate(faceRect.width() / 2 - elementRect.width() / 2, faceRect.height() / 2 - elementRect.height() / 2);
+        glassPainter.translate(faceRect.width() / (2 * devicePixelRatio()) - elementRect.width() / 2, faceRect.height() / (2 * devicePixelRatio()) - elementRect.height() / 2);
         m_theme->paint(&glassPainter, elementRect, "HandCenterScrew");
         glassPainter.restore();
 
-        m_theme->paint(&glassPainter, faceRect, "Glass");
+        m_theme->paint(&glassPainter, targetRect, "Glass");
 
         // get vertical translation, see drawHand() for more details
         m_verticalTranslation = m_theme->elementRect("ClockFace").center().y();
@@ -447,18 +457,17 @@ void Kclock::paintInterface(QPainter *p, const QRect &rect)
         m_handsCache.fill(Qt::transparent);
 
         QPainter handsPainter(&m_handsCache);
-        handsPainter.drawPixmap(faceRect, m_faceCache, faceRect);
+        handsPainter.drawPixmap(targetRect, m_faceCache, faceRect);
         handsPainter.setRenderHint(QPainter::SmoothPixmapTransform);
 
-        drawHand(&handsPainter, faceRect, m_verticalTranslation, hours, "Hour");
-        drawHand(&handsPainter, faceRect, m_verticalTranslation, minutes, "Minute");
+        drawHand(&handsPainter, targetRect, m_verticalTranslation, hours, "Hour");
+        drawHand(&handsPainter, targetRect, m_verticalTranslation, minutes, "Minute");
     }
 
     // reset repaint cache flag
     m_repaintCache = RepaintNone;
 
     // paint caches and second hand
-    QRect targetRect = faceRect;
     if (targetRect.width() < rect.width()) {
         targetRect.moveLeft((rect.width() - targetRect.width()) / 2);
     }
