@@ -43,7 +43,6 @@
 #include <QX11Info>
 
 #include "themepage.h"
-#include "themepage.moc"
 
 #include "thememodel.h"
 #include "itemdelegate.h"
@@ -152,7 +151,7 @@ void ThemePage::updateSizeComboBox()
                 maxIconHeight = m_pixmap.height();
             sizeComboBox->addItem(
                 QIcon(m_pixmap),
-                i18nc("@item:inlistbox size", "resolution dependent"),
+                i18nc("@item:inlistbox size", "Resolution dependent"),
                 0);
             comboBoxList << 0;
             foreach (i, sizes)
