@@ -34,7 +34,7 @@ class AddLayoutDialog: public QDialog
 	Q_OBJECT
 
 public:
-	AddLayoutDialog(const Rules* rules, Flags* flags, bool showLabel, QWidget* parent=NULL);
+	AddLayoutDialog(const Rules* rules, Flags* flags, const QString& model, bool showLabel, QWidget* parent=NULL);
 
 	LayoutUnit getSelectedLayoutUnit() { return selectedLayoutUnit; }
 	QString getvariant(QString variant);
@@ -43,11 +43,14 @@ public:
 public Q_SLOTS:
 	void languageChanged(int langIdx);
 	void layoutChanged(int layoutIdx);
+#ifdef NEW_GEOMETRY
 	void preview();
+#endif
 
 private:
 	const Rules* rules;
 	Flags* flags;
+	const QString& model;
 	Ui_AddLayoutDialog* layoutDialogUi;
 	QString selectedLanguage;
 	QString selectedLayout;
