@@ -18,13 +18,10 @@
 
 #include "layouts_menu.h"
 
-#include <kmenu.h>
 #include <ktoolinvocation.h>
 #include <klocalizedstring.h>
-#include <kdebug.h>
 
 #include <QAction>
-#include <QMenu>
 
 #include "keyboard_config.h"
 #include "x11_helper.h"
@@ -81,7 +78,7 @@ int LayoutsMenu::switchToLayout(const LayoutUnit& layoutUnit, const KeyboardConf
 		res = X11Helper::setLayout(layoutUnit);
 	}
 	else {
-		kWarning() << "switchToLayout with unknown layout" << layoutUnit.toString();
+		qWarning() << "switchToLayout with unknown layout" << layoutUnit.toString();
 		res = -1;
 	}
 	return res;
@@ -102,7 +99,7 @@ QAction* LayoutsMenu::createAction(const LayoutUnit& layoutUnit) const
 QList<QAction*> LayoutsMenu::contextualActions()
 {
 	if( actionGroup ) {
-		disconnect(actionGroup, SIGNAL(triggered(QAction*)), this, SLOT(actionTriggered(QAction*)));
+		disconnect(actionGroup, &QActionGroup::triggered, this, &LayoutsMenu::actionTriggered);
 		delete actionGroup;
 	}
 	actionGroup = new QActionGroup(this);
@@ -137,6 +134,6 @@ QList<QAction*> LayoutsMenu::contextualActions()
 	QAction* configAction = new QAction(i18n("Configure..."), actionGroup);
 	actionGroup->addAction(configAction);
 	configAction->setData("config");
-	connect(actionGroup, SIGNAL(triggered(QAction*)), this, SLOT(actionTriggered(QAction*)));
+	connect(actionGroup, &QActionGroup::triggered, this, &LayoutsMenu::actionTriggered);
 	return actionGroup->actions();
 }
