@@ -30,18 +30,23 @@
 #include <X11/extensions/XInput.h>
 #endif
 
+#ifdef HAVE_XCB_XINPUT
+#include <xcb/xinput.h>
+#endif
+
 #include "x11_helper.h"
 
 #include <fixx11h.h>
 
-static int DEVICE_NONE = 0;
-static int DEVICE_KEYBOARD = 1;
-static int DEVICE_POINTER = 2;
+static const int DEVICE_NONE = 0;
+static const int DEVICE_KEYBOARD = 1;
+static const int DEVICE_POINTER = 2;
 
 XInputEventNotifier::XInputEventNotifier(QWidget* parent):
 	XEventNotifier(), //TODO: destruct properly?
 	xinputEventType(-1)
 {
+  Q_UNUSED(parent)
 }
 
 void XInputEventNotifier::start()
@@ -78,9 +83,9 @@ bool XInputEventNotifier::processOtherEvents(xcb_generic_event_t* event)
 
 #ifdef HAVE_XINPUT_AND_DEVICE_NOTIFY
 
-extern "C" {
-    extern int _XiGetDevicePresenceNotifyEvent(Display *);
-}
+//extern "C" {
+//    extern int _XiGetDevicePresenceNotifyEvent(Display *);
+//}
 
 // This is ugly but allows to skip multiple execution of setxkbmap 
 // for all keyboard devices that don't care about layouts
@@ -95,28 +100,27 @@ static bool isRealKeyboard(const char* deviceName)
 int XInputEventNotifier::getNewDeviceEventType(xcb_generic_event_t* event)
 {
 	int newDeviceType = DEVICE_NONE;
-
-#if 0
-	if( xinputEventType != -1 && event->type == xinputEventType ) {
-		XDevicePresenceNotifyEvent *xdpne = (XDevicePresenceNotifyEvent*) event;
+#ifdef HAVE_XCB_XINPUT
+	if( xinputEventType != -1 && event->response_type == xinputEventType ) {
+		xcb_input_device_presence_notify_event_t *xdpne = reinterpret_cast<xcb_input_device_presence_notify_event_t *>(event);
 		if( xdpne->devchange == DeviceEnabled ) {
 			int ndevices;
-			XDeviceInfo	*devices = XListInputDevices(xdpne->display, &ndevices);
+			XDeviceInfo *devices = XListInputDevices(display, &ndevices);
 			if( devices != NULL ) {
-//				kDebug() << "New device id:" << xdpne->deviceid;
+				qCDebug(KCM_KEYBOARD) << "New device id:" << xdpne->device_id;
 				for(int i=0; i<ndevices; i++) {
-//					kDebug() << "id:" << devices[i].id << "name:" << devices[i].name << "used as:" << devices[i].use;
-					if( devices[i].id == xdpne->deviceid ) {
+					qCDebug(KCM_KEYBOARD) << "id:" << devices[i].id << "name:" << devices[i].name << "used as:" << devices[i].use;
+					if( devices[i].id == xdpne->device_id ) {
 						if( devices[i].use == IsXKeyboard || devices[i].use == IsXExtensionKeyboard ) {
 							if( isRealKeyboard(devices[i].name) ) {
 								newDeviceType = DEVICE_KEYBOARD;
-								qDebug() << "new keyboard device, id:" << devices[i].id << "name:" << devices[i].name << "used as:" << devices[i].use;
+								qCDebug(KCM_KEYBOARD) << "new keyboard device, id:" << devices[i].id << "name:" << devices[i].name << "used as:" << devices[i].use;
 								break;
 							}
 						}
 						if( devices[i].use == IsXPointer || devices[i].use == IsXExtensionPointer ) {
 							newDeviceType = DEVICE_POINTER;
-							qDebug() << "new pointer device, id:" << devices[i].id << "name:" << devices[i].name << "used as:" << devices[i].use;
+							qCDebug(KCM_KEYBOARD) << "new pointer device, id:" << devices[i].id << "name:" << devices[i].name << "used as:" << devices[i].use;
 							break;
 						}
 					}
@@ -129,14 +133,15 @@ int XInputEventNotifier::getNewDeviceEventType(xcb_generic_event_t* event)
 	return newDeviceType;
 }
 
-int XInputEventNotifier::registerForNewDeviceEvent(Display* display)
+int XInputEventNotifier::registerForNewDeviceEvent(Display* display_)
 {
 	int xitype;
 	XEventClass xiclass;
+	display = display_;
 
 	DevicePresence(display, xitype, xiclass);
 	XSelectExtensionEvent(display, DefaultRootWindow(display), &xiclass, 1);
-	qDebug() << "Registered for new device events from XInput, class" << xitype;
+	qCDebug(KCM_KEYBOARD) << "Registered for new device events from XInput, class" << xitype;
 	xinputEventType = xitype;
 	return xitype;
 }
