@@ -38,10 +38,10 @@
 #include <KLocalizedString>
 #include <Plasma/PluginLoader>
 
-K_PLUGIN_FACTORY(KCMSplashScreenFactory, registerPlugin<KCMSplashScreen>();)
+K_PLUGIN_FACTORY_WITH_JSON(KCMSplashScreenFactory, "kcm_splashscreen.json", registerPlugin<KCMSplashScreen>();)
 
-KCMSplashScreen::KCMSplashScreen(QWidget* parent, const QVariantList& args)
-    : KCModule(parent, args)
+KCMSplashScreen::KCMSplashScreen(QObject* parent, const QVariantList& args)
+    : KQuickAddons::ConfigModule(parent, args)
     , m_config("ksplashrc")
     , m_configGroup(m_config.group("KSplash"))
 {
@@ -57,19 +57,6 @@ KCMSplashScreen::KCMSplashScreen(QWidget* parent, const QVariantList& args)
     roles[PluginNameRole] = "pluginName";
     roles[ScreenhotRole] = "screenshot";
     m_model->setItemRoleNames(roles);
-    QVBoxLayout* layout = new QVBoxLayout(this);
-
-    m_quickView = new QQuickView();
-    QWidget *widget = QWidget::createWindowContainer(m_quickView, this);
-    m_quickView->setResizeMode(QQuickView::SizeRootObjectToView);
-    Plasma::Package package = Plasma::PluginLoader::self()->loadPackage("Plasma/Generic");
-    package.setDefaultPackageRoot("plasma/kcms");
-    package.setPath("kcm_splashscreen");
-    m_quickView->rootContext()->setContextProperty("kcm", this);
-    m_quickView->setSource(QUrl::fromLocalFile(package.filePath("mainscript")));
-    setMinimumHeight(m_quickView->initialSize().height());
-
-    layout->addWidget(widget);
 }
 
 QList<Plasma::Package> KCMSplashScreen::availablePackages(const QString &component)
@@ -111,9 +98,11 @@ void KCMSplashScreen::setSelectedPlugin(const QString &plugin)
         return;
     }
 
+    if (!m_selectedPlugin.isEmpty()) {
+        setNeedsSave(true);
+    }
     m_selectedPlugin = plugin;
     emit selectedPluginChanged();
-    changed();
 }
 
 void KCMSplashScreen::load()
@@ -160,6 +149,7 @@ void KCMSplashScreen::save()
     }
 
     m_configGroup.sync();
+    setNeedsSave(false);
 }
 
 void KCMSplashScreen::defaults()
@@ -180,7 +170,7 @@ void KCMSplashScreen::test(const QString &plugin)
     QStringList arguments;
     arguments << plugin << "--test";
     if (proc.execute("ksplashqml", arguments)) {
-        QMessageBox::critical(this, i18n("Error"), i18n("Failed to successfully test the splash screen."));
+        QMessageBox::critical(0, i18n("Error"), i18n("Failed to successfully test the splash screen."));
     }
 }
 
